/*
 * JNpp - Java bindings for NPP, to be used with JCuda
 *
 * Copyright (c) 2010-2013 Marco Hutter - http://www.jcuda.org
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package jcuda.jnpp;


/**
 * Color Conversion Modes
 */
public class NppiColorConvMode
{
    public static final int NPPI_FROM_RGB_TO_YCBCR = 0;
    public static final int NPPI_FROM_YCBCR_TO_RGB = 1;


    /**
     * Returns the String identifying the given NppiColorConvMode
     *
     * @param m The NppiColorConvMode
     * @return The String identifying the given NppiColorConvMode
     */
    public static String stringFor(int m)
    {
        switch (m)
        {
            case NPPI_FROM_RGB_TO_YCBCR : return "NPPI_FROM_RGB_TO_YCBCR";
            case NPPI_FROM_YCBCR_TO_RGB : return "NPPI_FROM_YCBCR_TO_RGB";
        }
        return "INVALID NppiColorConvMode: " + m;
    }

    /**
     * Private constructor to prevent instantiation.
     */
    private NppiColorConvMode()
    {
    }

};
